@@ -1,11 +1,14 @@
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+console.log("start xn-xnote-overlay");
+//var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var Services = globalThis.Services || ChromeUtils.import("resource://gre/modules/Services.jsm").Services;
 
 // Load xnoteOverlayObj into the window.
 Services.scriptloader.loadSubScript("chrome://xnote/content/xnote-overlay.js", window, "UTF-8");
-Services.scriptloader.loadSubScript("chrome://xnote/content/xnote-columnnote.js", window, "UTF-8");
+//Services.scriptloader.loadSubScript("chrome://xnote/content/xnote-columnnote.js", window, "UTF-8");
 
 function onLoad(activatedWhileWindowOpen) {
-  //console.log (Services.appinfo.version);
+//  console.log (Services.appinfo.version);
+/*
   let layout = WL.injectCSS("resource://xnote/skin/xnote-overlay.css");
   WL.injectElements(`
 
@@ -30,17 +33,18 @@ function onLoad(activatedWhileWindowOpen) {
       <!--
         It seems the observes element is no longer working as of TB 68.
         Disabling now via JavaScript.
-      -->
+     
                 <observes element="xnote-context-modify" attribute="hidden"/>
-            </menuitem>
+                -->
+                       </menuitem>
            
             
     <menuseparator id="xnote-context-separator-after-delete">
-      <observes element="xnote-context-modify" attribute="hidden" />
+    <!--   <observes element="xnote-context-modify" attribute="hidden" />  -->
     </menuseparator>
     <menuitem id="xnote-context-reset-note-window" label="&resetNoteWindow.label;"
       oncommand="window.xnoteOverlayObj.context_resetNoteWindow();">
-      <observes element="xnote-context-modify" attribute="hidden"/>
+     <!--   <observes element="xnote-context-modify" attribute="hidden"/>  -->
     </menuitem>
         </menupopup>
     </menu>
@@ -58,20 +62,23 @@ function onLoad(activatedWhileWindowOpen) {
     </tree>
   
   `, ["chrome://xnote/locale/xnote-overlay.dtd"]);
-
-  window.xnoteColumnObj.onLoad();
+*/
+//  window.xnoteColumnObj.onLoad();
   window.xnoteOverlayObj.onLoad();
 
   // Taken from full-address-column@lukasz.kosson.net / Full Address column
   // Usually the column handler is added when the window loads.
   // In our setup it's added later and we may miss the first notification.
   // So we fire one ourserves.
-  if (window.gDBView && window.document.documentElement.getAttribute("windowtype") == "mail:3pane") {
-    Services.obs.notifyObservers(null, "MsgCreateDBView");
-  }
+
+//115  if (window.gDBView && window.document.documentElement.getAttribute("windowtype") == "mail:3pane") {
+ //   Services.obs.notifyObservers(null, "MsgCreateDBView");
+//  }
 }
 
 function onUnload(isAddOnShutDown) {
-  window.xnoteColumnObj.onUnload();
+//  window.xnoteColumnObj.onUnload();
+//console.log("close xn-xn-overlay",window.xnoteOverlayObj);
   window.xnoteOverlayObj.onUnload();
+//  console.log("close xn-xn-overlay, unloaded");
 }
