@@ -6,14 +6,17 @@
   # Description : Functions associated with the XNote window (xnote-window.xul).
 */
 
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+//var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var Services = globalThis.Services || ChromeUtils.import("resource://gre/modules/Services.jsm").Services;
 var { xnote } = ChromeUtils.import("resource://xnote/modules/xnote.jsm");
 
 var xnoteColumnObj = function () {
 
   function getHeaderForRow(row) {
-    return gDBView.getFolderForViewIndex(row).
-      GetMessageHeader(gDBView.getKeyAt(row));
+    console.error("deprec:  getHeaderForRow");
+    return "";
+   //115 return gDBView.getFolderForViewIndex(row).
+  //115    GetMessageHeader(gDBView.getKeyAt(row));
   }
 
   var pub = {
@@ -91,11 +94,13 @@ var xnoteColumnObj = function () {
     },
 
     addCustomColumnHandler: function () {
-      gDBView.addColumnHandler("xnoteCol", pub.columnHandler);
+  //    gDBView.addColumnHandler("xnoteCol", pub.columnHandler);
+      gDBView.addColumnHandler("locationCol", pub.columnHandler);
     },
 
     removeCustomColumnHandler: function () {
-      gDBView.removeColumnHandler("xnoteCol");
+  //    gDBView.removeColumnHandler("xnoteCol");
+      gDBView.removeColumnHandler("locationCol");
     }
   }
 
