@@ -6,7 +6,9 @@
   # Description : Functions associated with the XNote window (xnote-window.xul).
 */
 var { XPCOMUtils } = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+//var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
+var Services = globalThis.Services || ChromeUtils.import("resource://gre/modules/Services.jsm").Services;
+
 
 XPCOMUtils.defineLazyScriptGetter(
   this,
@@ -40,55 +42,91 @@ window.xnoteWindowObj = function () {
    * Exécutée au chargement du post-it avant qu'elle ne soit affichée à l'écran.
    * C'est ici, que l'on peut modifier le style de la fenêtre dynamiquement
    */
-  pub.onLoad = function (e) {
-    //~ dump('\n->onLoad');
-    // premet l'accès au préférences
-    /*try
-    {
-      self.document.getElementById('xnote-note').style.setProperty('-moz-opacity', pref.getIntPref('xnote.transparence')/10, '');
-    }
-    catch(e) {}*/
-    
-    Services.scriptloader.loadSubScript("chrome://xnote/content/scripts/notifyTools.js", pub, "UTF-8");
 
-    // Capture the Window focus lost event to update the XNote tag.
-    addEventListener('blur', window.xnoteWindowObj.updateTag, true);
-    addEventListener('unload', window.xnoteWindowObj.onUnload, false);
 
-    //Necessary for correct shutdown as we are otherwise unable to correctly
-    //save a modified note
-    opener.addEventListener("unload", window.xnoteWindowObj.onOpenerUnload, false);
-    //Unfortunately, there seems to be no better way to react on window
-    //movement.
-    setInterval(window.xnoteWindowObj.checkOpenerMoved, 500);
-
-    note = self.arguments[0];
+  pub.keys = [],
 
+  pub.onBlur = function() {
+    pub.saveNote();
+  //  window.xnoteWindowObj.updateTag
     let texte = self.document.getElementById('xnote-texte');
-    texte.value = note.text;
+    pub.updateTag(texte.value);
+ },
+    pub.onLoad = async function (e) {
+      //~ dump('\n->onLoad');
+      // premet l'accès au préférences
+      /*try
+      {
+        self.document.getElementById('xnote-note').style.setProperty('-moz-opacity', pref.getIntPref('xnote.transparence')/10, '');
+      }
+      catch(e) {}*/
 
-    let fwd = self.document.getElementById('xnote-button-forward');
-    fwd.href = "mailto:?body=" + encodeURI(note.text);
+      Services.scriptloader.loadSubScript("chrome://xnote/content/scripts/notifyTools.js", pub, "UTF-8");
 
-    //PrintUtils.showPageSetup();
-    //self.print();
+      let closeKey = await pub.notifyTools.notifyBackground({ command: "getCommandKey" });
 
+      //console.log("wind", window, window.opener, opener, typeof(window.addEventListener), opener === window.opener,addEventListener===window.addEventListener , typeof(addEventlistener));
 
-    //set date in the titlebar
-    let modificationdate = self.document.getElementById("xnote-mdate");
-    modificationdate.value = note.modificationDate;
+      pub.keys["Alt"] = false;
+      pub.keys["Shift"] = false;
+      pub.keys["Ctrl"] = false;
+      pub.keys["key"] = "";
+      
+
+      let comm = await closeKey.shortcut.split("+");
+      pub.keys["key"] = comm[comm.length - 1].toLowerCase();
+      for (let i = comm.length - 2; i > -1; i--) {
+        pub.keys[comm[i]] = true;
+      };
+      //   console.log("leg", closeKey, pub.keys, comm);
 
 
 
-    self.setTimeout(window.xnoteWindowObj.resizeWindow);
+      // Capture the Window focus lost event to update the XNote tag.
+      addEventListener('blur', window.xnoteWindowObj.onBlur, true);
+      addEventListener('unload', window.xnoteWindowObj.onUnload, false);
+      //window.addEventListener("resize", window.xnoteWindowObj.resize, false);
+      //Necessary for correct shutdown as we are otherwise unable to correctly
+      //save a modified note
+      opener.addEventListener("unload", window.xnoteWindowObj.onOpenerUnload, false);
+      //Unfortunately, there seems to be no better way to react on window
+      //movement.
+      setInterval(window.xnoteWindowObj.checkOpenerMoved, 500);
 
-    if (window.arguments[1])
-      texte.focus();
-    else
-      self.setTimeout(window.opener.focus);
-    //~ dump('\n<-onLoad');
+      note = self.arguments[0];
 
-  }
+      let texte = self.document.getElementById('xnote-texte');
+      texte.value = note.text;
+
+      //if the same key opens and closes, we need this, otherwise the window closes immediately
+      setTimeout(() => { texte.addEventListener("keyup", window.xnoteWindowObj.onInput, false); }, 300);
+      let fwd = self.document.getElementById('xnote-button-forward');
+      fwd.href = "mailto:?body=" + encodeURI(note.text);
+
+      //PrintUtils.showPageSetup();
+      //self.print();
+
+
+      //set date in the titlebar
+     // let modificationdate = self.document.getElementById("xnote-mdate");
+     // modificationdate.value = note.modificationDate;
+
+      document.title = "XNote  " + note.modificationDate;
+
+
+
+      self.setTimeout(window.xnoteWindowObj.resizeWindow,0);
+
+      if (window.arguments[1]) {
+        texte.focus();
+//        console.log("wnd has arg 1");
+      }
+      else {
+        self.setTimeout(window.opener.focus,0);
+      //~ dump('\n<-onLoad');
+//      console.log("wnd has no arg 1");
+    }
+    }
 
   function resizeWindow(width, height) {
     width = width < 58 ? 58 : width;
@@ -103,6 +141,15 @@ window.xnoteWindowObj = function () {
     resizeWindow(note.width, note.height);
   }
 
+  pub.onInput = function (ev) {
+    // console.log("ev", ev);
+    if ((ev.key == pub.keys["key"]) && (ev.altKey == pub.keys["Alt"]) && (ev.shiftKey == pub.keys["Shift"]) && (ev.ctrlKey == pub.keys["Ctrl"])) {
+      //  console.log("got it");
+      //  pub.saveNote();  done in onUnload
+      window.close();
+    };
+  }
+
   /**
    * CALLING XUL
    * Type: blur event of the XUL element <window>
@@ -113,7 +160,11 @@ window.xnoteWindowObj = function () {
    */
   pub.updateTag = function () {
     //~ dump('\n->updateTag');
-    opener.xnoteOverlayObj.updateTag(document.getElementById('xnote-texte').value);
+  //  opener.gTabmail.currentAbout3Pane.xnoteOverlayObj.updateTag(document.getElementById('xnote-texte').value);
+ //102
+ let texte = self.document.getElementById('xnote-texte');
+  
+  opener.xnoteOverlayObj.updateTag(texte.value);
     //~ dump('\n<-updateTag');
   }
 
@@ -220,10 +271,10 @@ window.xnoteWindowObj = function () {
     //messagePaneBrowser.currentWindowGlobal = window;
     //messagePaneBrowser.top = window;
     //messagePaneBrowser.currentWindowGlobal = window;
-    console.log("msbro", messagePaneBrowser);
+  //  console.log("msbro", messagePaneBrowser);
     messagePaneBrowser.contentDocument.documentElement.textContent = "eee";
     //messagePaneBrowser.contentDocument.textContent = "jjj";
-    console.log("brodoc", messagePaneBrowser.contentDocument);
+  //  console.log("brodoc", messagePaneBrowser.contentDocument);
     mainWindow.PrintUtils.startPrintWindow(messagePaneBrowser.browsingContext, {});
    
     var printContents = document.getElementById("xnote-texte").cloneNode(true);
@@ -266,20 +317,29 @@ window.xnoteWindowObj = function () {
     self.print();
   }
 
+
+pub.searchXNotes = function () {
+ // console.log("xnote search clicked");
+//  window.close();
+  pub.notifyTools.notifyBackground({ command: "searchXNotes" });
+
+}
+
+
   pub.copyNoteToClipboard = function () {
     let clipboard = Cc["@mozilla.org/widget/clipboardhelper;1"].getService(Ci.nsIClipboardHelper);
     clipboard.copyString(note.text);
     /*
-    console.log("wnd", window, "doc", window.document);
+  //  console.log("wnd", window, "doc", window.document);
      var res;
      window.document.designMode = "on";
     // let docb = window.document.getElementById("body");
     // console.log("body", docb);
      res = window.document.execCommand("selectAll");
-     console.log("selectAll", res);
+   //  console.log("selectAll", res);
   
      res = window.document.execCommand("copy");
-     console.log("copy", res);
+  //   console.log("copy", res);
    */
   }
 
@@ -296,7 +356,10 @@ window.xnoteWindowObj = function () {
     //~ dump('\n->supprimerNote');
     document.getElementById('xnote-texte').value = '';
     pub.noteModified();
-    pub.saveNote();
+    //to correctly set tag
+    note.text = "";
+    note.saveNote();
+    opener.xnoteOverlayObj.updateTag("");
     //~ dump('\n<-supprimerNote');
   }
 
@@ -327,7 +390,7 @@ window.xnoteWindowObj = function () {
    */
   pub.redimenssionnement = function (e) {
     //~ dump('\n w.document.width='+window.document.width+' ; w.document.height='+window.document.height);
-
+//console.log("redimenssionnement");
     //~ dump('\nlargeur='+document.getElementById('xnote-texte').style.width);
     let newWidth = widthBeforeMove + e.screenX - xBeforeMove;
     let newHeight = heightBeforeMove + e.screenY - yBeforeMove;
@@ -336,7 +399,15 @@ window.xnoteWindowObj = function () {
     resizeWindow(newWidth, newHeight);
     pub.noteModified();
   }
+pub.resize = function() { //not working
+ // console.log("resize");
+  //window.resizeTo(width, height);
+  document.getElementById("xnote-texte").style.height = (window.innerHeight - 40) + "px";
 
+  //resizeWindow(window.innerWidth, window.innerHeight);
+  
+
+},
   /**
    * quand le bouton de la souris est relaché, on supprime la capture
    * du déplacement de la souris.
@@ -357,13 +428,18 @@ window.xnoteWindowObj = function () {
   }
 
   pub.onUnload = function (e) {
+  //  console.log("unload XNote wnd");
     //    ~dump("\n->onUnload");
     //console.log("note unLoad");
     pub.saveNote();
-    removeEventListener('blur', window.xnoteWindowObj.updateTag);
+    let texte = self.document.getElementById('xnote-texte');
+    pub.updateTag(texte.value);
+    removeEventListener('blur', window.xnoteWindowObj.onBlur);
     removeEventListener('load', window.xnoteWindowObj.onLoad);
     removeEventListener('unload', window.xnoteWindowObj.onUnload);
     opener.removeEventListener("unload", window.xnoteWindowObj.onOpenerUnload);
+    texte.removeEventListener("keyup", window.xnoteWindowObj.onInput);
+  //  window.removeEventListener("resize", window.xnoteWindowObj.redimenssionnement);
   }
 
   pub.onOpenerUnload = function (e) {
