@@ -1,5 +1,6 @@
-var { ExtensionCommon } = ChromeUtils.import("resource://gre/modules/ExtensionCommon.jsm"),
-  { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm"),
+var { ExtensionCommon } = ChromeUtils.import("resource://gre/modules/ExtensionCommon.jsm");//,
+//  { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm"),
+  var Services = globalThis.Services || ChromeUtils.import("resource://gre/modules/Services.jsm").Services;
   win = Services.wm.getMostRecentWindow("mail:3pane");
 
 
