@@ -8,6 +8,8 @@ var prefs = bgPage.getPreferences();
 
 var btnSelectStoragePath = document.getElementById("btnSelectStoragePath");
 
+var btnHlp = document.getElementById("btnHlp");
+
 function isInputType(node, type) {
   return node.nodeName.toLowerCase() == "input" && node.type.toLowerCase() == type.toLowerCase();
 }
@@ -96,7 +98,8 @@ async function savePrefs() {
           console.error(node);
       }
     }
-  }
+  };
+//  console.log("prefs", prefs);
   bgPage.setPreferences(prefs);
 }
 
@@ -146,8 +149,15 @@ async function initOptions() {
     }
   }
 
+
+  function openHelpPage() {
+    let url = browser.runtime.getURL("popup/update.html");
+    messenger.tabs.create({url});
+  }
+
   btnSave.addEventListener('click', savePrefs);
   btnSelectStoragePath.addEventListener('click', selectStoragePath);
+  btnHlp.addEventListener('click', openHelpPage);
 
 }
 
